@@ -35,7 +35,8 @@ cat coord.txt | xargs -I {} -n 1 bash -c 'echo -e "samtools mpileup -DguS -f $1
 echo -e "wait\n" 
 
 # Got to cat the bcf files back together
-find `pwd`/tmpbcf | grep -e "bcf$" > bcflist.txt
-echo "bcftools cat -f bcflist.txt > merge.bcf && bcftools view merge.bcf > merge.vcf"
+# find `pwd`/tmpbcf | grep -e "bcf$" > bcflist.txt
+# Didn't work with the -f option not sure why
+echo "find `pwd`/tmpbcf/*bcf | xargs bcftools cat > merge.bcf && bcftools view merge.bcf > merge.vcf"
 
 rm coord.txt
